@@ -9,13 +9,15 @@ from colr import color
 
 from mypvdevices.ModbusConnection import ModbusConnection
 
+BUILDNR = "1.2011.35"
+
 JOINTIMEOUT = 5
 SERIALLEN = 16
 DEVICESLEEPTIME = 5
 DEFAULTMODBUSFREQUENCY = 3
 
 class Device:
-    __firmwareVersion__ = "1.1.1"
+    __firmwareVersion__ = "1." + str(BUILDNR)
     __deviceType__ = "Dummy-Device"
     __lock__ = None
     __running__ = False
